@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "23fed4f5b5cf0aaa216c2088261a14501e9c4daa",
-  "branchName": "release-client-5.x",
-  "buildTime": "2023-09-15 10:07:55 GMT",
-  "buildVersion": "5.1.727",
+  "commitId": "cc4055ff848eede21731c56714fa75095c18b55d",
+  "branchName": "release-client-5.16.1",
+  "buildTime": "2023-09-21 12:36:37 GMT",
+  "buildVersion": "5.1.733",
   "css": [
-    "@zoom/client-calendar/static/css/chunk-vendors.dc891ce4.css",
+    "@zoom/client-calendar/static/css/chunk-vendors.d4ae17e7.css",
     "@zoom/client-calendar/static/css/app.c3b5793e.css"
   ],
   "js": [
-    "@zoom/client-calendar/static/js/chunk-vendors.14206689.js",
-    "@zoom/client-calendar/static/js/app.aa7bcce3.js"
+    "@zoom/client-calendar/static/js/chunk-vendors.5be8367f.js",
+    "@zoom/client-calendar/static/js/app.29f5ad99.js"
   ],
   "key": "@zoom/client-calendar"
 };
