@@ -1,16 +1,16 @@
 ;(function(){
   var map = {
-  "commitId": "e9703c4d610ffcbd5eb4a60be830672deec038da",
-  "branchName": "release-client-5.x",
-  "buildTime": "Wed, 13 Sep 2023 08:04:12 GMT",
-  "buildVersion": "5.1.419",
+  "commitId": "06ded6ba39876a57ea37418bac954d186bd080e6",
+  "branchName": "release-client-5.16.1",
+  "buildTime": "Tue, 19 Sep 2023 06:23:12 GMT",
+  "buildVersion": "5.1.424",
   "css": [
     "@zoom/client-scheduler/static/css/chunk-vendors.af34567c.css",
     "@zoom/client-scheduler/static/css/index.f31cf0bd.css"
   ],
   "js": [
     "@zoom/client-scheduler/static/js/chunk-vendors.ca68f063.js",
-    "@zoom/client-scheduler/static/js/index.33235476.js"
+    "@zoom/client-scheduler/static/js/index.8779959b.js"
   ]
 };
   var prefix = 'https://dev-integration.zoomdev.us/fe-static/';
